@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,7 +60,6 @@ void add_user(struct w *widgets)
     G_CONST_RETURN gchar *username;
     G_CONST_RETURN gchar *password;
     G_CONST_RETURN gchar *group;
-    G_CONST_RETURN gchar *homedir;
     G_CONST_RETURN gchar *comment;
     G_CONST_RETURN gchar *shell;
 
@@ -68,7 +67,6 @@ void add_user(struct w *widgets)
     password  = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[1]));
     group     = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[2]));
     comment   = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[3]));
-    homedir   = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[4]));
     /* Shell is a gtk_combo_box_entry_new_text */
     shell     = gtk_entry_get_text(GTK_ENTRY(GTK_BIN(widgets->user_set_combo[0])->child));
 
@@ -141,16 +139,6 @@ void add_user(struct w *widgets)
     	return;
     }
 
-    /* If the directory field has 0 chars we inform that this cant be done */
-    length = strlen(homedir);
-    if( length < 8 )  /* /home/b /var/abc */
-    {
-	info = g_strdup_printf(_("Failed adding user: %s\nThe specified home directory is too short.\n"), username);
-	show_info(info);
-	g_free(info);
-    	return;
-    }
-
     /* A comment is required */
     length = strlen(comment);
     if( length == 0 ) 
