@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,71 +107,16 @@ void add_firestarter_user_pre()
     g_free(conf);
 }
 
-/* Change firestarters INIF configuration line to use br0 */
-/* INIF="br0" is the internal network interface when bridged. */
-void switch_firestarter_internal_interface()
-{
-    FILE *fp;
-    long file_size = 0;
-    char *line, *new_conf;
-    gchar *cmd, *info;
-
-    if((fp=fopen(FIRESTARTER_CONFIG, "r"))==NULL)
-    {
-	/* Dont show a popup */
-	return;
-    }
-    fseek(fp, 0, SEEK_END);
-    file_size = ftell(fp);
-    rewind(fp);
-
-    line = allocate(file_size+1);
-    new_conf = allocate(file_size+1024);
-
-    if( file_size > 1 )
-    while(fgets(line, file_size, fp)!=NULL)
-    {
-        if( cmplowercase(line, "inif=") )
-	{
-	   strcat(new_conf, "INIF=\"br0\"\n");
-	}
-	else
-	  strcat(new_conf, line);
-    }
-    fclose(fp);
-    free(line);
-
-    /* Write a new configuration with the altered INIF setting */
-    if((fp=fopen(FIRESTARTER_CONFIG, "w+"))==NULL)
-    {
-	/* Show a popup */
-	free(new_conf);
-	return;
-    }
-    fputs(new_conf, fp);
-    fclose(fp);
-    free(new_conf);
-
-    /* Reconfigure firestarter to use the new setting */
-    cmd = g_strdup_printf("%s --generate-scripts", FIRESTARTER_BINARY);
-    if( ! run_command(cmd) )
-    {
-	info = g_strdup_printf(_("Error reconfiguring firestarters configuration with this command:\n%s\n"), cmd);
-	show_info(info);
-	g_free(info);
-    }
-    g_free(cmd);
-}
-
 
+/* Writes the server configuration and sysinit script.
+   Also writes a client configuration suited for this server. */
 void apply_server_settings(struct w *widgets)
 {
-    /* Writes the server configuration and sysinit script.
-       Writes a client configuration suited for this server. */
     FILE *fp;
-    int i = 0;
+    char *tmp1, *tmp2;
+    int i = 0, z = 0;
     gint active_index;
-    gchar *info, *cmd;
+    gchar *info, *cmd, *client_dns_line;
     gchar *sysinit_script_path, *sysinit_start_script;
     gchar *conf, *openvpn_server_conf, *openvpn_client_conf;
     gchar *firestarter_start, *firestarter_stop;
@@ -185,6 +130,9 @@ void apply_server_settings(struct w *widgets)
     G_CONST_RETURN gchar *lan_subnet_mask;
     G_CONST_RETURN gchar *lan_broadcast_address;
     G_CONST_RETURN gchar *client_address_range;
+    G_CONST_RETURN gchar *server_user;
+    G_CONST_RETURN gchar *server_group;
+    G_CONST_RETURN gchar *client_dns;
 
     /* Spin buttons */
     G_CONST_RETURN gchar *server_port;
@@ -192,8 +140,6 @@ void apply_server_settings(struct w *widgets)
     G_CONST_RETURN gchar *log_level;
     G_CONST_RETURN gchar *ping_interval;
     G_CONST_RETURN gchar *ping_timeout;
-    G_CONST_RETURN gchar *server_user;
-    G_CONST_RETURN gchar *server_group;
 
     /* Combos */
     gchar *proto=NULL, *tap_dev=NULL, *require_auth=NULL;
@@ -201,6 +147,7 @@ void apply_server_settings(struct w *widgets)
     gchar *redirect_gateway=NULL, *compression=NULL;
     gchar *share_internet=NULL, *client_auth_line=NULL;
 
+
     /* Certificate settings are saved when generating certificates */
 
     /* Entries */
@@ -213,6 +160,7 @@ void apply_server_settings(struct w *widgets)
     client_address_range   = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[6]));
     server_user            = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[7]));
     server_group           = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[8]));
+    client_dns             = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_entry[9]));
 
     /* Spin buttons */
     server_port   = gtk_entry_get_text(GTK_ENTRY(widgets->server_set_spinbutton[0]));
@@ -274,12 +222,12 @@ void apply_server_settings(struct w *widgets)
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[2]));
     if( active_index == 0 )
     {
-        require_auth = g_strdup_printf("\n"); /* "No" */
+        require_auth = g_strdup_printf("\n");
         client_auth_line = g_strdup_printf("\n");
     }
     else
     {
-        require_auth = g_strdup_printf("plugin %s login\nusername-as-common-name\n", OPENVPN_AUTH_PAM_PLUGIN); /* "Yes" */
+        require_auth = g_strdup_printf("plugin %s login\nusername-as-common-name\n", OPENVPN_AUTH_PAM_PLUGIN);
         client_auth_line = g_strdup_printf("auth-user-pass %s/client/passfile\n", OPENVPN_SYSCONF_DIR);
     }
 
@@ -333,44 +281,52 @@ void apply_server_settings(struct w *widgets)
 	    break;
 	}
 	share_internet = g_strconcat(
-	IP_FORWARD_CMD_START, "\n",
-	"iptables -t nat -A POSTROUTING -s ", lan_net_addr, "/", lan_subnet_mask, " -o eth0\n",
+	"	", IP_FORWARD_CMD_START, "\n",
+	"	iptables -t nat -A POSTROUTING -o ", external_iface_name, " -j MASQUERADE\n",
 	NULL);
 
 	g_free(lan_net_addr);
     }
     else
-      share_internet = g_strdup_printf("%s\n", IP_FORWARD_CMD_STOP);
+      share_internet = g_strdup_printf("\t%s\n", IP_FORWARD_CMD_STOP);
 
 
     /* If Firestarter is used, add sysinit script parts and setup firestarter. */
     active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[8]));
     if( active_index == 1 )
     {
-	/* Add Firestarter iptables tap+ settings to
-           the user-pre file if it exists */
+	/* Add Firestarter iptables tap+ settings to the user-pre file if it exists */
 	add_firestarter_user_pre();
 
-	/* Switches Firestarters internal interface to
-           br0 in the configuration file if it exists */
-	switch_firestarter_internal_interface();
-
-	/* Start script part for Firestarter */    
+	/* Start script part for Firestarter including a sleep loop with a timeout */
 	firestarter_start = g_strconcat(
-	"# Update Firestarter scripts and start Firestarter if its not running.\n",
-	"if [ ! -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
-	"    ", FIRESTARTER_BINARY, " --generate-scripts\n",
-	"    ", FIRESTARTER_BINARY, " -s\n",
-	"fi\n",
+	"	# Start Firestarter if its not running.\n",
+	"	if [ ! -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
+	"	   # Wait a while for the LAN interface to come up so that firestarter can start.\n",
+	"	   count=0\n",
+	"	   max_wait=15\n",
+	"	   while [ 1 ]; do\n",
+	"		sleep 1\n",
+	"		let \"count+=1\"\n",
+	"		ip addr show ", lan_iface_name, " | grep -q \"inet \" && break\n",
+	"		echo \"Waiting for interfaces to come up...\"\n",
+	"		if [ $count -gt $max_wait ]; then\n",
+	"		   echo \"Wait for interfaces - Giving up.\"\n",
+        "		   break\n",
+	"	   	fi\n",
+	"	   done\n",
+	"    	   ", FIRESTARTER_BINARY, " -s\n",
+	"	fi\n",
+	"\n",
 	share_internet,
 	NULL);
 
-	/* Stop script part for Firestarter */    
+	/* Stop script part for Firestarter */
 	firestarter_stop = g_strconcat(
-	"# Stop Firestarter if its running.\n",
-	"if [ -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
-	"    ", FIRESTARTER_BINARY, " -p\n",
-	"fi\n",
+	"	# Stop Firestarter if its running.\n",
+	"	if [ -e /var/lock/subsys/firestarter -o -e /var/lock/firestarter ]; then\n",
+	"    	   ", FIRESTARTER_BINARY, " -p\n",
+	"	fi\n",
 	NULL);
 	
 	non_firestarter_start = g_strdup_printf("\n");
@@ -380,21 +336,19 @@ void apply_server_settings(struct w *widgets)
     {
 	/* Instead of firestarter configuring iptables, we do it. */
 	non_firestarter_start = g_strconcat(
-	"# Run some iptable rules for the LAN network and VPN-clients.\n",
-	"iptables -A INPUT  -i tap+ -j ACCEPT\n",
-	"iptables -A OUTPUT -o tap+ -j ACCEPT\n",
-	"iptables -A FORWARD -i tap+ -j ACCEPT\n",
+	"	# Run some iptable rules for the LAN network and VPN-clients.\n",
+	"	iptables -A INPUT   -i tap+ -j ACCEPT\n",
+	"	iptables -A OUTPUT  -o tap+ -j ACCEPT\n",
+	"	iptables -A FORWARD -i tap+ -j ACCEPT\n",
 	share_internet,
 	NULL);
 
 	/* Disallow input and output on tap interfaces.
 	   Restart the LAN network interface. Doesnt work otherwise. */
 	non_firestarter_stop = g_strconcat(
-	"iptables -D INPUT  -i tap+ -j ACCEPT\n",
-	"iptables -D OUTPUT -o tap+ -j ACCEPT\n",
-	"iptables -D FORWARD -i tap+ -j ACCEPT\n",
-	"ifconfig ", lan_iface_name, " down\n",
-	"ifconfig ", lan_iface_name, " up\n",
+	"	iptables -D INPUT   -i tap+ -j ACCEPT\n",
+	"	iptables -D OUTPUT  -o tap+ -j ACCEPT\n",
+	"	iptables -D FORWARD -i tap+ -j ACCEPT\n",
 	NULL);
 	/* Dont remove any internet sharing. */
 	
@@ -403,6 +357,46 @@ void apply_server_settings(struct w *widgets)
     }
     g_free(share_internet);
 
+
+    /* Client DNS servers */
+    if( client_dns == NULL || strlen(client_dns) < 20 )
+    {
+	client_dns_line = g_strdup_printf("\n");
+    }
+    else
+    {
+	/* Space separated list of DNS's in the entry. */
+	tmp1 = allocate(1024);
+	tmp2 = allocate(1024*3);
+
+	for(i=0; client_dns[i]!='\0'; i++)
+	if( client_dns[i]!=' ' && client_dns[i]!='\t' )
+	{
+	    snprintf(tmp1, 1000, "%s", &client_dns[i]);
+
+	    /* Snip after the new dns. */
+	    for(z=0; strlen(tmp1); z++)
+	    if( tmp1[z]==' ' || tmp1[z]=='\t' || tmp1[z]=='\0' )
+	    {
+		tmp1[z]='\0';
+
+		strcat(tmp2, "push \"dhcp-option DNS ");
+		strcat(tmp2, tmp1);
+		strcat(tmp2, "\"\n");
+		break;
+	    }
+	    for(i=i; client_dns[i]!='\0'; i++)
+	      if( client_dns[i]==' ' || client_dns[i]=='\t' )
+	        break;
+	}
+
+	client_dns_line = g_strdup_printf("%s", tmp2);
+	
+	free(tmp1);
+	free(tmp2);
+    }
+
+
     /* Write the openvpn server configuration file:
        /etc/gadmin-openvpn/server/gadmin-openvpn-server.conf */
     openvpn_server_conf = g_strdup_printf("%s/server/gadmin-openvpn-server.conf", OPENVPN_SYSCONF_DIR);
@@ -424,6 +418,7 @@ void apply_server_settings(struct w *widgets)
 	g_free(non_firestarter_start);
 	g_free(non_firestarter_stop);
 	g_free(client_auth_line);
+	g_free(client_dns_line);
         return;
     }
 
@@ -457,11 +452,16 @@ void apply_server_settings(struct w *widgets)
     "status /etc/gadmin-openvpn/server/openvpn-server-status.log\n",
     "verb ", log_level, "\n",
     "mute 20\n",
+    client_dns_line,
     NULL);
 
     fputs(conf, fp);
     fclose(fp);
-    g_free(openvpn_server_conf);
+
+    if( openvpn_server_conf!=NULL )
+      g_free(openvpn_server_conf);
+    if( client_dns_line!=NULL )
+      g_free(client_dns_line);
 
 
     /* Write the client configuration */
@@ -510,6 +510,11 @@ void apply_server_settings(struct w *widgets)
     "status /etc/gadmin-openvpn/client/openvpn-client-status.log\n",
     "verb ", log_level, "\n",
     "mute 20\n",
+    "ping 10\n",
+    "ping-restart 0\n",
+    "pull\n",
+    "allow-pull-fqdn\n",
+    "resolv-retry infinite\n",
     NULL);
 
     fputs(conf, fp);
@@ -517,8 +522,6 @@ void apply_server_settings(struct w *widgets)
     g_free(openvpn_client_conf);
     g_free(client_auth_line);
 
-
-
     g_free(proto);
     g_free(require_auth);
     g_free(cipher);
@@ -528,13 +531,12 @@ void apply_server_settings(struct w *widgets)
     /* tap_dev is freed after the init script below... */
 
 
-
     /* Write the servers sysinit script according to the settings */
     sysinit_start_script = g_strconcat(
     "#!/bin/bash\n",
     "#\n",
     "#\n",
-    "# chkconfig: 2345 10 30\n",
+    "# chkconfig: 2345 90 30\n",
     "#\n",
     "# processname: gadmin-openvpn-server\n",
     "# description: This shell script takes care of starting and stopping \\n",
@@ -542,23 +544,23 @@ void apply_server_settings(struct w *widgets)
     "#\n",
     "### BEGIN INIT INFO\n",
     "# Provides: gadmin-openvpn-server\n",
-    "# Required-Start: network NetworkManager\n",
-    "# Required-Stop: NetworkManager\n",
+    "# Required-Start: $network\n",
+    "# Required-Stop: $network\n",
     "# Default-Start: 2 3 4 5\n",
     "# Default-Stop: 0 1 6\n",
     "# Short-Description: start and stop gadmin-openvpn-server\n",
     "# Description: GAdmin-OpenVPN-Server starts and stops a bridged VPN server.\n",
     "### END INIT INFO\n",
     "\n",
+    "PATH=/sbin:/usr/sbin:/bin:/usr/bin:/usr/local/sbin:/usr/local/bin\n",
     "\n",
-    "# Define Bridge Interface\n",
+    "# Define the bridge interface.\n",
     "br=\"br0\"\n",
     "\n",
-    "# Define list of TAP interfaces to be bridged,\n",
-    "# for example tap=\"tap0 tap1 tap2\".\n",
+    "# Define a list of TAP interfaces to be bridged.\n",
     "tap=\"", tap_dev, "\"\n",
     "\n",
-    "# LAN Interface to be bridged with TAP interface(s) above.\n",
+    "# LAN interface to be bridged with TAP interface(s) above.\n",
     "# Should not be the same LAN network address as connecting clients have.\n",
     "external_iface_name=\"", external_iface_name, "\"\n",
     "lan_iface_name=\"", lan_iface_name, "\"\n",
@@ -566,58 +568,59 @@ void apply_server_settings(struct w *widgets)
     "lan_iface_netmask=\"", lan_subnet_mask, "\"\n",
     "lan_iface_broadcast=\"", lan_broadcast_address, "\"\n",
     "\n",
-    "\n",
     "case \"$1\" in\n",
-    "		start)\n",
+    "	start)\n",
     "\n",
     firestarter_stop,
     "\n",
-    "modprobe tun\n",
-    "modprobe bridge\n",
+    "	modprobe tun\n",
+    "	modprobe bridge\n",
     "\n",
-    "for t in $tap; do\n",
-    "    openvpn --mktun --dev $t\n",
-    "done\n",
+    "	for t in $tap; do\n",
+    "	    openvpn --mktun --dev $t\n",
+    "	done\n",
     "\n",
-    "brctl addbr $br\n",
-    "brctl addif $br $lan_iface_name\n",
+    "	brctl addbr $br\n",
+    "	brctl addif $br $lan_iface_name\n",
     "\n",
-    "for t in $tap; do\n",
-    "    brctl addif $br $t\n",
-    "done\n",
+    "	for t in $tap; do\n",
+    "	    brctl addif $br $t\n",
+    "	done\n",
     "\n",
-    "for t in $tap; do\n",
-    "    ifconfig $t 0.0.0.0 promisc up\n",
-    "done\n",
+    "	for t in $tap; do\n",
+    "	    ifconfig $t 0.0.0.0 promisc up\n",
+    "	done\n",
     "\n",
-    "ifconfig $lan_iface_name 0.0.0.0 promisc up\n",
+    "	ifconfig $lan_iface_name 0.0.0.0 promisc up\n",
     "\n",
-    "ifconfig $br $lan_iface_ip netmask $lan_iface_netmask broadcast $lan_iface_broadcast\n",
+    "	ifconfig $br $lan_iface_ip netmask $lan_iface_netmask broadcast $lan_iface_broadcast\n",
     "\n",
-    "openvpn --daemon --script-security 2 --writepid /var/run/openvpn/openvpn.pid \\\n",
-    "--config ", OPENVPN_SYSCONF_DIR, "/server/gadmin-openvpn-server.conf --cd ", OPENVPN_SYSCONF_DIR, "/server\n",
+    "	mkdir -p /var/run/openvpn\n",
+    "\n",
+    "	openvpn --daemon --script-security 2 --writepid /var/run/openvpn/openvpn-server.pid \\\n",
+    "	--config ", OPENVPN_SYSCONF_DIR, "/server/gadmin-openvpn-server.conf --cd ", OPENVPN_SYSCONF_DIR, "/server\n",
     "\n",
     firestarter_start,
     non_firestarter_start,
-    ";;\n",
+    "	;;\n",
     "\n",
-    "		stop)\n",
+    "	stop)\n",
     "\n",
-    "killall -9 openvpn\n",
+    "	killall -9 openvpn\n",
     "\n",
     non_firestarter_stop,
     "\n",
-    "ifconfig $br down\n",
-    "brctl delbr $br\n",
+    "	ip link set $br down\n",
+    "	brctl delbr $br\n",
     "\n",
-    "for t in $tap; do\n",
-    "    openvpn --rmtun --dev $t\n",
-    "done\n",
-    ";;\n",
-    "		*)\n",
-    "echo \"usage gadmin-openvpn-server {start|stop}\"\n",
-    "exit 1\n",
-    ";;\n",
+    "	for t in $tap; do\n",
+    "	    openvpn --rmtun --dev $t\n",
+    "	done\n",
+    "	;;\n",
+    "	*)\n",
+    "	echo \"usage gadmin-openvpn-server {start|stop}\"\n",
+    "	exit 1\n",
+    "	;;\n",
     "esac\n",
     "\n",
     "exit 0\n",
