@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -59,27 +59,20 @@ void apply_user(struct w *widgets)
     groupname = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[2]));
     comment   = gtk_entry_get_text(GTK_ENTRY(widgets->user_set_entry[3]));
 
-    /* If the user has written a password thats less then MIN_PASS_LEN chars long */
-//    if( strlen(password) > 0 && password_length < MIN_PASS_LEN )
-    if( strlen(password) > 0 && strlen(password) < 6 ) // MIN_PASS_LEN )
+    /* Make sure we have a valid password */
+    if( strlen(password) > 0 && strlen(password) < 6 )
     {
-//	info = g_strdup_printf(_("The minimum password length is %d.\n"), MIN_PASS_LEN);
 	info = g_strdup_printf(_("The minimum password length is %d.\n"), 6);
 	show_info(info);
 	g_free(info);
         return;
     }
 
-
     password_user(username, password);
 
-
     /* Write a client CCD file if the CCD textview contains data */
     write_client_ccd_file(widgets, username);
 
-    /* Update the userlist */
-    populate_users(widgets);
-
     /* Populate the user settings */
     populate_user_settings(widgets);
 
