@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -150,40 +150,3 @@ int file_exists(char *infile)
     fclose(fp);
     return 1;
 }
-
-
-// This function is not used
-int using_tls(void)
-{
-    FILE *fp;
-    int retval = 0;
-    char *buffy;    
-
-return 0;
-
-    /* Dont show TLS options if we dont have the module */
-    if((fp=popen("sendmail -l","r"))==NULL)
-    {
-	/* Locale trouble could be one cause so add TLS options */
-	retval = 1;
-    }
-    else
-      {	
-	 buffy = allocate(MAX_READ_POPEN+1);
-	 while(fgets(buffy, MAX_READ_POPEN, fp)!=NULL)
-	 {
-	    if( strstr(buffy, "mod_tls") )
-	    {
-	        retval = 1;
-	        break;
-	    }
-	 }
-	 free(buffy);
-         pclose(fp);
-      }
-
-    /* For testing wo ssl widgets use */
-    /* retval = 0;  */
-    
-    return retval;
-}
