@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,9 +34,6 @@
 #include "generate_cert.h"
 #include "create_server_settings.h"
 
-extern int use_tls;
-
-
 
 void create_server_settings(struct w *widgets)
 {
@@ -258,14 +255,21 @@ void create_server_settings(struct w *widgets)
 
     /* Server user */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The server runs as this user: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The server drops root privileges and runs as this user"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("The server drops root privileges and runs as this user"), NULL);
     a++; b++; ent++;
 
     /* Server group */
     widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" The server runs as this group: "), 0,1,a,b,200);
-    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent], _("The server drops root privileges and runs as this group"), NULL);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("The server drops root privileges and runs as this group"), NULL);
     a++; b++; ent++;
 
+    /* Client DNS servers */
+    widgets->server_set_entry[ent] = make_long_entry_with_label(GTK_TABLE(widgets->srv_set_table), _(" Client DNS servers: "), 0,1,a,b,200);
+    gtk_tooltips_set_tip(tooltips, widgets->server_set_entry[ent],
+    _("If not empty the server will push this space separated list of DNS-addresses to the VPN-clients."), NULL);
+    a++; b++; ent++;
 
     /* A hseparator */
     make_3columns_hseparator(GTK_TABLE(widgets->srv_set_table), 0,1,a,b);
