@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,8 +36,8 @@ extern int activated;
 
 void deactivate_button_clicked(struct w *widgets)
 {
-    if( ! activated )
-      return;
+    /* Always run init_stop to remove
+       any sysinit symlinks */
 
     init_stop(widgets);
 }
