@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include "export_button_clicked.h"
 
 
-
+/* Main GUI export button clicked */
 void export_button_clicked(struct w *widgets)
 {
     gchar *info, *cmd, *path;
@@ -60,7 +60,6 @@ void export_button_clicked(struct w *widgets)
     }
     g_free(path);
 
-
     /* Copy server certs and keys to the client directory. */
     cmd = g_strdup_printf("cp %s/server/certs/{cacert.pem,cert.pem,dh.pem,key.pem,ta.key} %s/server/client/certs/",
 									OPENVPN_SYSCONF_DIR, OPENVPN_SYSCONF_DIR);
@@ -74,31 +73,6 @@ void export_button_clicked(struct w *widgets)
     }
     g_free(cmd);
 
-
-    /* Tar up the client configuration directory and put it in the server directory. */
-    cmd = g_strdup_printf("cd %s/server && tar -zcf gadmin-openvpn-client-data.tar.gz client/", OPENVPN_SYSCONF_DIR);
-    if( ! run_command(cmd) )
-    {
-	info = g_strdup_printf(_("Error: Could not pack client configuration and certificates.\n"));
-        show_info(info);
-        g_free(info);
-        g_free(cmd);
-        return;
-    }
-    g_free(cmd);
-
-    path = g_strdup_printf("%s/server/gadmin-openvpn-client-data.tar.gz", OPENVPN_SYSCONF_DIR);
-    if( ! file_exists(path) )
-    {
-	info = g_strdup_printf(_("Error: No client configuration package has been created. Is the tar package installed ?.\n"));
-	show_info(info);
-	g_free(info);
-	g_free(path);
-	return;
-    }
-    g_free(path);
-
-
     /* Show the export window */
     show_export_window(widgets);
 }
