@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -750,9 +750,7 @@ fix_path(char *path)
 void randomize_username(struct w *widgets)
 {
     char *rnd_string;
-    char *homedir_username;
-    gchar *info, *utf8=NULL;
-    gchar *default_homedir;
+    gchar *utf8=NULL;
     int len = 6; /* Default username length */
 
     rnd_string = random_string(len);
@@ -760,50 +758,10 @@ void randomize_username(struct w *widgets)
     /* Insert the randomized username in the username entry */    
     utf8 = g_locale_to_utf8(rnd_string, strlen(rnd_string), NULL, NULL, NULL);
     gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[0]), utf8);
-
-    if( utf8!=NULL )
-      g_free(utf8);
-
-    /* Insert the randomized username after the path in the homedir entry */    
-    homedir_username = allocate(16384);
-
-    default_homedir = g_strdup_printf("%s", USERSHOME);
-    if( strlen(default_homedir) > 8192 )
-    {
-	info = g_strdup_printf(_("Max home directory length is 8192 chars.\n"));
-	show_info(info);
-	g_free(info);
-	free(homedir_username);
-	g_free(default_homedir);
-	free(rnd_string);
-	return;
-    }
-
-    snprintf(homedir_username, 8192, "%s", default_homedir);
-    
-    /* Strip some slashes and things we dont want */
-    if( homedir_username[strlen(homedir_username)-1]=='/' )
-        homedir_username[strlen(homedir_username)-1]='\0';
-
-    if( homedir_username[strlen(homedir_username)-1]=='/' )
-        homedir_username[strlen(homedir_username)-1]='\0';
-
-    if( homedir_username[strlen(homedir_username)-1]=='*' )
-        homedir_username[strlen(homedir_username)-1]='\0';
-
-    /* Add a slash to the end then the username */
-    strcat(homedir_username, "/");
-    strcat(homedir_username, rnd_string);
-
-    utf8 = g_locale_to_utf8(homedir_username, strlen(homedir_username), NULL, NULL, NULL);
-    gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), utf8);
-
     if( utf8!=NULL )
       g_free(utf8);
     
     free(rnd_string);
-    free(homedir_username);
-    g_free(default_homedir);
 }
 
 
