@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,12 +35,12 @@
 
 
 
+/* Populates the server tab */
 void populate_server_settings(struct w *widgets)
 {
-    /* Populates the server tab */
     FILE *fp;
     int i = 0, x = 0, have_sysinit_script = 0;
-    int share_internet = 0;
+    int count = 0, share_internet = 0;
     int have_firestarter_line = 0;
     long val = 0, file_size = 0;
     char *line, *tmp;
@@ -50,14 +50,14 @@ void populate_server_settings(struct w *widgets)
     gchar *openvpn_openssl_conf;
 
     /* Clear all non certificate entries. */
-    for(i=0; i<8; i++)
+    for(i=0; i<10; i++)
       gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[i]), "");
 
     /* Set default values for combos 0 to 7. */
     for(i=0; i<8; i++)
     {
-	/* Some combos should be set to "Yes" or the second choise. */
-	if( i == 0 || i == 2 || i == 4 || i == 6 || i == 7 )
+	/* Some combos should default to "Yes" or the second choise. */
+	if( i == 0 || i == 2 || i == 4 || i == 5 || i == 6 || i == 7 )
 	  gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[i]), 1);
 	else
 	  gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[i]), 0);
@@ -475,6 +475,41 @@ void populate_server_settings(struct w *widgets)
 	    if( utf8!=NULL )
 	      g_free(utf8);
 	}
+
+	/* Client DNS servers */
+	if( cmplowercase(line, "dhcp-option dns ") )
+	{
+	    i = 0;
+	    /* Scroll to the address */
+	    for(count=0; count<3; count++)
+	    {
+		for(i=i; line[i]!='\0'; i++)
+	          if( line[i]!=' ')
+	    	    break;
+		for(i=i; line[i]!='\0'; i++)
+	          if( line[i]==' ' && line[i+1]!=' ' )
+	    	    break;
+	    }
+
+	    snprintf(tmp, 1000, "%s", &line[i+1]);
+
+	    if( tmp[strlen(tmp)-1]=='\n')
+	      tmp[strlen(tmp)-1]='\0';
+
+	    if( tmp[strlen(tmp)-1]=='"')
+	      tmp[strlen(tmp)-1]='\0';
+
+	    /* Space separated DNS list.
+	       Add spaces between addresses but not last. */
+	    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
+	    if( utf8!=NULL )
+	    {
+		gtk_entry_append_text(GTK_ENTRY(widgets->server_set_entry[9]), utf8);
+		/* Append a space, will leave one extra at the end. */
+		gtk_entry_append_text(GTK_ENTRY(widgets->server_set_entry[9]), " ");
+		g_free(utf8);
+	    }
+	}
     }
     fclose(fp);
     free(line);
@@ -578,7 +613,8 @@ void populate_server_settings(struct w *widgets)
 	    }
 
 	    /* Share internet. */
-	    if( cmplowercase(line, "iptables -t nat -a postrouting -s") )
+	    if( cmplowercase(line, "iptables -t nat -a postrouting -s")
+	    ||  cmplowercase(line, "iptables -t nat -a postrouting -o") )
 	    {
 		share_internet = 1;
 		gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[7]), 1);
@@ -596,7 +632,7 @@ void populate_server_settings(struct w *widgets)
     }
     g_free(openvpn_sysinit_script);
 
-    /* We want sharing to be default*/
+    /* Set combos to "No" if not found. since they default to yes. */
     if( ! share_internet )
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->server_set_combo[7]), 0);
 
@@ -631,7 +667,7 @@ void populate_server_settings(struct w *widgets)
     }
 
 
-    /* Insert values from the openssl conf if it exists */
+    /* Insert values from openssl.conf if it exists. */
     openvpn_openssl_conf = g_strdup_printf("%s/server/certs/gadmin-openvpn-openssl.conf", OPENVPN_SYSCONF_DIR);
     if((fp=fopen(openvpn_openssl_conf, "r"))==NULL)
     {
@@ -659,10 +695,10 @@ void populate_server_settings(struct w *widgets)
 	    {
 		if( x >= 2 && line[x-2]=='=' )
 		{
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[9]), utf8);
+		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[10]), utf8);
 		    break;
 		}
 	    }
@@ -674,10 +710,10 @@ void populate_server_settings(struct w *widgets)
 	    {
 	        if( x >= 2 && line[x-2]=='=' )
 	        {
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[10]), utf8);
+		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[11]), utf8);
 		    break;
 		}
 	    }
@@ -689,10 +725,10 @@ void populate_server_settings(struct w *widgets)
 	    {
 	        if( x >= 2 && line[x-2]=='=' )
 		{
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[11]), utf8);
+		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[12]), utf8);
 		    break;
 	        }
 	    }
@@ -704,10 +740,10 @@ void populate_server_settings(struct w *widgets)
 	    {
 	        if( x >= 2 && line[x-2]=='=' )
 		{
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[12]), utf8);
+		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[13]), utf8);
 		    break;
 		}
 	    }
@@ -719,10 +755,10 @@ void populate_server_settings(struct w *widgets)
 	    {
 	        if( x >= 2 && line[x-2]=='=' )
 	        {
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[13]), utf8);
+		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[14]), utf8);
 		    break;
 		}
 	    }
@@ -734,10 +770,10 @@ void populate_server_settings(struct w *widgets)
 	    {
 	        if( x >= 2 && line[x-2]=='=' )
 	        {
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[14]), utf8);
+		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[15]), utf8);
 		    break;
 		}
 	    }
@@ -749,7 +785,7 @@ void populate_server_settings(struct w *widgets)
 	    {
 		if( x >= 2 && line[x-2]=='=' )
 		{
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    if( chars_are_digits(tmp) )
 		    {
@@ -767,7 +803,7 @@ void populate_server_settings(struct w *widgets)
 	    {
 	        if( x >= 2 && line[x-2]=='=' )
 	        {
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    if( chars_are_digits(tmp) )
 		    {
@@ -779,7 +815,7 @@ void populate_server_settings(struct w *widgets)
 	    }
         }
 
-	/* Password entry is located at 14 */
+	/* Password entry is located at 16 */
 
 	/* Country code */
 	if( strstr(line, "countryName = ") )
@@ -788,10 +824,10 @@ void populate_server_settings(struct w *widgets)
 	    {
 		if( x >= 2 && line[x-2]=='=' )
 		{
-		    snprintf(tmp, line[x]+x, line+x);
+		    snprintf(tmp, line[x]+x, "%s", line+x);
 		    tmp[strlen(tmp)-1]='\0';
 		    utf8 = g_locale_to_utf8(tmp, strlen(tmp), NULL, NULL, NULL);
-		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[16]), utf8);
+		    gtk_entry_set_text(GTK_ENTRY(widgets->server_set_entry[17]), utf8);
 		    break;
 		}
 	    }
