@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -69,9 +69,6 @@ void populate_user_settings(struct w *widgets)
 	/* Comment */
 	gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[3]), "");
 
-	/* Home directory */
-	gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), "/home/SomeUserName");
-
 	/* Shell */
 	gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->user_set_combo[0]), 0);
     }
@@ -104,15 +101,6 @@ void populate_user_settings(struct w *widgets)
     if( utf8!=NULL )
       g_free(utf8);
 
-
-    /* Insert home directory */
-    user_item = get_user_setting(username, "homedir");
-    utf8 = g_locale_to_utf8(user_item, strlen(user_item), NULL, NULL, NULL);
-    gtk_entry_set_text(GTK_ENTRY(widgets->user_set_entry[4]), utf8);
-    g_free(user_item);
-    if( utf8!=NULL )
-      g_free(utf8);
-
     /* Get the users shell and select it. If the shell combo has
        this shell in its list(/etc/shells), then select it. Otherwise select /dev/null */
     user_item = get_user_setting(username, "shell");
