@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn server.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "allocate.h"
 #include "show_info.h"
 #include "functions.h"
+#include "commands.h"
 #include "chars_are_digits.h"
 
 extern int MAX_READ_POPEN;
@@ -40,22 +41,30 @@ void set_version(struct w *widgets)
     FILE *fp;
     char *line;
     int i = 0, count = 0, ver_found = 0;
-    gchar *command;
+    gchar *cmd;
     gchar *ver=NULL;
     gchar *utf8=NULL;
     gchar *info;
     GdkColor color;
 
-    command = g_strdup_printf("%s --version < /dev/null | grep -i openvpn", OPENVPN_BINARY);
-    if((fp=popen(command, "r"))==NULL)
+    cmd = g_strdup_printf("%s --version | grep -i openvpn", OPENVPN_BINARY);
+    if( ! run_command(cmd) )
     {
         info = g_strdup_printf(_("OpenVPN does not seem to be installed. Set version failed.\n"));
         show_info(info);
         g_free(info);
-        g_free(command);
+        g_free(cmd);
         return;
     }
-    g_free(command);
+    if((fp=popen(cmd, "r"))==NULL)
+    {
+        info = g_strdup_printf(_("OpenVPN does not seem to be installed. Set version popen failed.\n"));
+        show_info(info);
+        g_free(info);
+        g_free(cmd);
+        return;
+    }
+    g_free(cmd);
 
     line = allocate(MAX_READ_POPEN);
 
@@ -97,16 +106,15 @@ void set_version(struct w *widgets)
     g_free(ver);
     pclose(fp);
 
-    /* Check for bridge-utils */
-    command = g_strdup_printf("%s --version < /dev/null | grep -i bridge-utils", BRCTL_BINARY);
-    if((fp=popen(command, "r"))==NULL)
+    /* Check for bridge-utils. */
+    cmd = g_strdup_printf("%s --version", BRCTL_BINARY);
+    if( ! run_command(cmd) )
     {
         info = g_strdup_printf(_("Error: Bridge-utils does not seem to be installed.\n"));
         show_info(info);
         g_free(info);
-        g_free(command);
+        g_free(cmd);
         return;
     }
-    g_free(command);
-    pclose(fp);
+    g_free(cmd);
 }
